@@ -41,6 +41,7 @@ class URLError(Exception):
 
 
 class Bugzilla(object):
+    """A Bugzilla server."""
 
     __slots__ = [
         '_products', '_fields', '_user_cache',
@@ -48,6 +49,36 @@ class Bugzilla(object):
         'server',
     ]
 
+    @classmethod
+    def from_config(cls, conf, **kwargs):
+        """Instantiate a Bugzilla according to given Config and args.
+
+        The 'server', 'url', 'user' and 'password' keyword arguments are
+        required, but may be ``None``.
+        """
+        mandatory_args = set(['server', 'url', 'user', 'password'])
+        mandatory_args -= kwargs.viewkeys()
+        if mandatory_args:
+            raise TypeError('Mandatory args ({}) not supplied'.format(
+                ', '.join("'{}'".format(arg) for arg in mandatory_args)))
+
+        if kwargs['server'] is None and conf.has_option('core', 'server'):
+            kwargs['server'] = conf.get('core', 'server')
+
+        _server = {}
+        if kwargs['server']:
+            try:
+                _server = dict(conf.items('server.' + kwargs['server']))
+            except config.NoSectionError:
+                raise UserWarning(
+                    "No configuration for server '{}'."
+                    .format(kwargs['server'])
+                )
+        _server.update(
+            {k: kwargs[k] for k in ('url', 'user', 'password') if kwargs[k]}
+        )
+        return cls(**_server)
+
     def __init__(self, url=None, user=None, password=None, **config):
         """Create a Bugzilla XML-RPC client.
 
@@ -78,7 +109,7 @@ class Bugzilla(object):
             )
         url = url + 'xmlrpc.cgi' if url[-1] == '/' else url + '/xmlrpc.cgi'
         # httplib explodes if url is unicode
-        self.server = xmlrpclib.ServerProxy(str(url))
+        self.server = xmlrpclib.ServerProxy(str(url), use_datetime=True)
 
     def rpc(self, *args, **kwargs):
         """Do an RPC on the Bugzilla server.
